# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/greenplum/v1/config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/mdb/greenplum/v1/config.proto',
  package='yandex.cloud.mdb.greenplum.v1',
  syntax='proto3',
  serialized_options=b'\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplum',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*yandex/cloud/mdb/greenplum/v1/config.proto\x12\x1dyandex.cloud.mdb.greenplum.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"P\n\tResources\x12\x1a\n\x12resource_preset_id\x18\x01 \x01(\t\x12\x11\n\tdisk_size\x18\x02 \x01(\x03\x12\x14\n\x0c\x64isk_type_id\x18\x03 \x01(\t\"\x90\x02\n\x16\x43onnectionPoolerConfig\x12L\n\x04mode\x18\x01 \x01(\x0e\x32>.yandex.cloud.mdb.greenplum.v1.ConnectionPoolerConfig.PoolMode\x12)\n\x04size\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x38\n\x13\x63lient_idle_timeout\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"C\n\x08PoolMode\x12\x19\n\x15POOL_MODE_UNSPECIFIED\x10\x00\x12\x0b\n\x07SESSION\x10\x01\x12\x0f\n\x0bTRANSACTION\x10\x02\"U\n\x16MasterSubclusterConfig\x12;\n\tresources\x18\x01 \x01(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.Resources\"V\n\x17SegmentSubclusterConfig\x12;\n\tresources\x18\x01 \x01(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.Resources\"\xd3\x03\n\x13GreenplumConfig6_17\x12\x34\n\x0fmax_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x16max_slot_wal_keep_size\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x42\n\x1dgp_workfile_limit_per_segment\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12@\n\x1bgp_workfile_limit_per_query\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x46\n!gp_workfile_limit_files_per_query\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12>\n\x19max_prepared_transactions\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x17gp_workfile_compression\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\xcf\x04\n\x13GreenplumConfig6_19\x12\x34\n\x0fmax_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x16max_slot_wal_keep_size\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x42\n\x1dgp_workfile_limit_per_segment\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12@\n\x1bgp_workfile_limit_per_query\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x46\n!gp_workfile_limit_files_per_query\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12>\n\x19max_prepared_transactions\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x17gp_workfile_compression\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x11max_statement_mem\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x42\n\rlog_statement\x18\t \x01(\x0e\x32+.yandex.cloud.mdb.greenplum.v1.LogStatement\"\x81\x02\n\x16GreenplumConfigSet6_17\x12R\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_17B\x04\xe8\xc7\x31\x01\x12G\n\x0buser_config\x18\x02 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_17\x12J\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_17\"\x81\x02\n\x16GreenplumConfigSet6_19\x12R\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_19B\x04\xe8\xc7\x31\x01\x12G\n\x0buser_config\x18\x02 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_19\x12J\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_19\"\x8d\x02\n\x19\x43onnectionPoolerConfigSet\x12U\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.mdb.greenplum.v1.ConnectionPoolerConfigB\x04\xe8\xc7\x31\x01\x12J\n\x0buser_config\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.mdb.greenplum.v1.ConnectionPoolerConfig\x12M\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x35.yandex.cloud.mdb.greenplum.v1.ConnectionPoolerConfig*R\n\x0cLogStatement\x12\x1d\n\x19LOG_STATEMENT_UNSPECIFIED\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\x07\n\x03\x44\x44L\x10\x02\x12\x07\n\x03MOD\x10\x03\x12\x07\n\x03\x41LL\x10\x04\x42p\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplumb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])

_LOGSTATEMENT = _descriptor.EnumDescriptor(
  name='LogStatement',
  full_name='yandex.cloud.mdb.greenplum.v1.LogStatement',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LOG_STATEMENT_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NONE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DDL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MOD', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALL', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2528,
  serialized_end=2610,
)
_sym_db.RegisterEnumDescriptor(_LOGSTATEMENT)

LogStatement = enum_type_wrapper.EnumTypeWrapper(_LOGSTATEMENT)
LOG_STATEMENT_UNSPECIFIED = 0
NONE = 1
DDL = 2
MOD = 3
ALL = 4


_CONNECTIONPOOLERCONFIG_POOLMODE = _descriptor.EnumDescriptor(
  name='PoolMode',
  full_name='yandex.cloud.mdb.greenplum.v1.ConnectionPoolerConfig.PoolMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='POOL_MODE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SESSION', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRANSACTION', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=428,
  serialized_end=495,
)
_sym_db.RegisterEnumDescriptor(_CONNECTIONPOOLERCONFIG_POOLMODE)


_RESOURCES = _descriptor.Descriptor(
  name='Resources',
  full_name='yandex.cloud.mdb.greenplum.v1.Resources',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_preset_id', full_name='yandex.cloud.mdb.greenplum.v1.Resources.resource_preset_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disk_size', full_name='yandex.cloud.mdb.greenplum.v1.Resources.disk_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disk_type_id', full_name='yandex.cloud.mdb.greenplum.v1.Resources.disk_type_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=140,
  serialized_end=220,
)


_CONNECTIONPOOLERCONFIG = _descriptor.Descriptor(
  name='ConnectionPoolerConfig',
  full_name='yandex.cloud.mdb.greenplum.v1.ConnectionPoolerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='yandex.cloud.mdb.greenplum.v1.ConnectionPoolerConfig.mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='yandex.cloud.mdb.greenplum.v1.ConnectionPoolerConfig.size', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_idle_timeout', full_name='yandex.cloud.mdb.greenplum.v1.ConnectionPoolerConfig.client_idle_timeout', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONNECTIONPOOLERCONFIG_POOLMODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=223,
  serialized_end=495,
)


_MASTERSUBCLUSTERCONFIG = _descriptor.Descriptor(
  name='MasterSubclusterConfig',
  full_name='yandex.cloud.mdb.greenplum.v1.MasterSubclusterConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.greenplum.v1.MasterSubclusterConfig.resources', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=497,
  serialized_end=582,
)


_SEGMENTSUBCLUSTERCONFIG = _descriptor.Descriptor(
  name='SegmentSubclusterConfig',
  full_name='yandex.cloud.mdb.greenplum.v1.SegmentSubclusterConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.greenplum.v1.SegmentSubclusterConfig.resources', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=584,
  serialized_end=670,
)


_GREENPLUMCONFIG6_17 = _descriptor.Descriptor(
  name='GreenplumConfig6_17',
  full_name='yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_17',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_connections', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_17.max_connections', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_slot_wal_keep_size', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_17.max_slot_wal_keep_size', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gp_workfile_limit_per_segment', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_17.gp_workfile_limit_per_segment', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gp_workfile_limit_per_query', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_17.gp_workfile_limit_per_query', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gp_workfile_limit_files_per_query', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_17.gp_workfile_limit_files_per_query', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_prepared_transactions', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_17.max_prepared_transactions', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gp_workfile_compression', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_17.gp_workfile_compression', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=673,
  serialized_end=1140,
)


_GREENPLUMCONFIG6_19 = _descriptor.Descriptor(
  name='GreenplumConfig6_19',
  full_name='yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_19',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_connections', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_19.max_connections', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_slot_wal_keep_size', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_19.max_slot_wal_keep_size', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gp_workfile_limit_per_segment', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_19.gp_workfile_limit_per_segment', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gp_workfile_limit_per_query', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_19.gp_workfile_limit_per_query', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gp_workfile_limit_files_per_query', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_19.gp_workfile_limit_files_per_query', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_prepared_transactions', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_19.max_prepared_transactions', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gp_workfile_compression', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_19.gp_workfile_compression', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_statement_mem', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_19.max_statement_mem', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_statement', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_19.log_statement', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1143,
  serialized_end=1734,
)


_GREENPLUMCONFIGSET6_17 = _descriptor.Descriptor(
  name='GreenplumConfigSet6_17',
  full_name='yandex.cloud.mdb.greenplum.v1.GreenplumConfigSet6_17',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='effective_config', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumConfigSet6_17.effective_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_config', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumConfigSet6_17.user_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_config', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumConfigSet6_17.default_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1737,
  serialized_end=1994,
)


_GREENPLUMCONFIGSET6_19 = _descriptor.Descriptor(
  name='GreenplumConfigSet6_19',
  full_name='yandex.cloud.mdb.greenplum.v1.GreenplumConfigSet6_19',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='effective_config', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumConfigSet6_19.effective_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_config', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumConfigSet6_19.user_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_config', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumConfigSet6_19.default_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1997,
  serialized_end=2254,
)


_CONNECTIONPOOLERCONFIGSET = _descriptor.Descriptor(
  name='ConnectionPoolerConfigSet',
  full_name='yandex.cloud.mdb.greenplum.v1.ConnectionPoolerConfigSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='effective_config', full_name='yandex.cloud.mdb.greenplum.v1.ConnectionPoolerConfigSet.effective_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_config', full_name='yandex.cloud.mdb.greenplum.v1.ConnectionPoolerConfigSet.user_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_config', full_name='yandex.cloud.mdb.greenplum.v1.ConnectionPoolerConfigSet.default_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2257,
  serialized_end=2526,
)

_CONNECTIONPOOLERCONFIG.fields_by_name['mode'].enum_type = _CONNECTIONPOOLERCONFIG_POOLMODE
_CONNECTIONPOOLERCONFIG.fields_by_name['size'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CONNECTIONPOOLERCONFIG.fields_by_name['client_idle_timeout'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CONNECTIONPOOLERCONFIG_POOLMODE.containing_type = _CONNECTIONPOOLERCONFIG
_MASTERSUBCLUSTERCONFIG.fields_by_name['resources'].message_type = _RESOURCES
_SEGMENTSUBCLUSTERCONFIG.fields_by_name['resources'].message_type = _RESOURCES
_GREENPLUMCONFIG6_17.fields_by_name['max_connections'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_GREENPLUMCONFIG6_17.fields_by_name['max_slot_wal_keep_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_GREENPLUMCONFIG6_17.fields_by_name['gp_workfile_limit_per_segment'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_GREENPLUMCONFIG6_17.fields_by_name['gp_workfile_limit_per_query'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_GREENPLUMCONFIG6_17.fields_by_name['gp_workfile_limit_files_per_query'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_GREENPLUMCONFIG6_17.fields_by_name['max_prepared_transactions'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_GREENPLUMCONFIG6_17.fields_by_name['gp_workfile_compression'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_GREENPLUMCONFIG6_19.fields_by_name['max_connections'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_GREENPLUMCONFIG6_19.fields_by_name['max_slot_wal_keep_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_GREENPLUMCONFIG6_19.fields_by_name['gp_workfile_limit_per_segment'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_GREENPLUMCONFIG6_19.fields_by_name['gp_workfile_limit_per_query'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_GREENPLUMCONFIG6_19.fields_by_name['gp_workfile_limit_files_per_query'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_GREENPLUMCONFIG6_19.fields_by_name['max_prepared_transactions'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_GREENPLUMCONFIG6_19.fields_by_name['gp_workfile_compression'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_GREENPLUMCONFIG6_19.fields_by_name['max_statement_mem'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_GREENPLUMCONFIG6_19.fields_by_name['log_statement'].enum_type = _LOGSTATEMENT
_GREENPLUMCONFIGSET6_17.fields_by_name['effective_config'].message_type = _GREENPLUMCONFIG6_17
_GREENPLUMCONFIGSET6_17.fields_by_name['user_config'].message_type = _GREENPLUMCONFIG6_17
_GREENPLUMCONFIGSET6_17.fields_by_name['default_config'].message_type = _GREENPLUMCONFIG6_17
_GREENPLUMCONFIGSET6_19.fields_by_name['effective_config'].message_type = _GREENPLUMCONFIG6_19
_GREENPLUMCONFIGSET6_19.fields_by_name['user_config'].message_type = _GREENPLUMCONFIG6_19
_GREENPLUMCONFIGSET6_19.fields_by_name['default_config'].message_type = _GREENPLUMCONFIG6_19
_CONNECTIONPOOLERCONFIGSET.fields_by_name['effective_config'].message_type = _CONNECTIONPOOLERCONFIG
_CONNECTIONPOOLERCONFIGSET.fields_by_name['user_config'].message_type = _CONNECTIONPOOLERCONFIG
_CONNECTIONPOOLERCONFIGSET.fields_by_name['default_config'].message_type = _CONNECTIONPOOLERCONFIG
DESCRIPTOR.message_types_by_name['Resources'] = _RESOURCES
DESCRIPTOR.message_types_by_name['ConnectionPoolerConfig'] = _CONNECTIONPOOLERCONFIG
DESCRIPTOR.message_types_by_name['MasterSubclusterConfig'] = _MASTERSUBCLUSTERCONFIG
DESCRIPTOR.message_types_by_name['SegmentSubclusterConfig'] = _SEGMENTSUBCLUSTERCONFIG
DESCRIPTOR.message_types_by_name['GreenplumConfig6_17'] = _GREENPLUMCONFIG6_17
DESCRIPTOR.message_types_by_name['GreenplumConfig6_19'] = _GREENPLUMCONFIG6_19
DESCRIPTOR.message_types_by_name['GreenplumConfigSet6_17'] = _GREENPLUMCONFIGSET6_17
DESCRIPTOR.message_types_by_name['GreenplumConfigSet6_19'] = _GREENPLUMCONFIGSET6_19
DESCRIPTOR.message_types_by_name['ConnectionPoolerConfigSet'] = _CONNECTIONPOOLERCONFIGSET
DESCRIPTOR.enum_types_by_name['LogStatement'] = _LOGSTATEMENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Resources = _reflection.GeneratedProtocolMessageType('Resources', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCES,
  '__module__' : 'yandex.cloud.mdb.greenplum.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.greenplum.v1.Resources)
  })
_sym_db.RegisterMessage(Resources)

ConnectionPoolerConfig = _reflection.GeneratedProtocolMessageType('ConnectionPoolerConfig', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTIONPOOLERCONFIG,
  '__module__' : 'yandex.cloud.mdb.greenplum.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.greenplum.v1.ConnectionPoolerConfig)
  })
_sym_db.RegisterMessage(ConnectionPoolerConfig)

MasterSubclusterConfig = _reflection.GeneratedProtocolMessageType('MasterSubclusterConfig', (_message.Message,), {
  'DESCRIPTOR' : _MASTERSUBCLUSTERCONFIG,
  '__module__' : 'yandex.cloud.mdb.greenplum.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.greenplum.v1.MasterSubclusterConfig)
  })
_sym_db.RegisterMessage(MasterSubclusterConfig)

SegmentSubclusterConfig = _reflection.GeneratedProtocolMessageType('SegmentSubclusterConfig', (_message.Message,), {
  'DESCRIPTOR' : _SEGMENTSUBCLUSTERCONFIG,
  '__module__' : 'yandex.cloud.mdb.greenplum.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.greenplum.v1.SegmentSubclusterConfig)
  })
_sym_db.RegisterMessage(SegmentSubclusterConfig)

GreenplumConfig6_17 = _reflection.GeneratedProtocolMessageType('GreenplumConfig6_17', (_message.Message,), {
  'DESCRIPTOR' : _GREENPLUMCONFIG6_17,
  '__module__' : 'yandex.cloud.mdb.greenplum.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_17)
  })
_sym_db.RegisterMessage(GreenplumConfig6_17)

GreenplumConfig6_19 = _reflection.GeneratedProtocolMessageType('GreenplumConfig6_19', (_message.Message,), {
  'DESCRIPTOR' : _GREENPLUMCONFIG6_19,
  '__module__' : 'yandex.cloud.mdb.greenplum.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_19)
  })
_sym_db.RegisterMessage(GreenplumConfig6_19)

GreenplumConfigSet6_17 = _reflection.GeneratedProtocolMessageType('GreenplumConfigSet6_17', (_message.Message,), {
  'DESCRIPTOR' : _GREENPLUMCONFIGSET6_17,
  '__module__' : 'yandex.cloud.mdb.greenplum.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.greenplum.v1.GreenplumConfigSet6_17)
  })
_sym_db.RegisterMessage(GreenplumConfigSet6_17)

GreenplumConfigSet6_19 = _reflection.GeneratedProtocolMessageType('GreenplumConfigSet6_19', (_message.Message,), {
  'DESCRIPTOR' : _GREENPLUMCONFIGSET6_19,
  '__module__' : 'yandex.cloud.mdb.greenplum.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.greenplum.v1.GreenplumConfigSet6_19)
  })
_sym_db.RegisterMessage(GreenplumConfigSet6_19)

ConnectionPoolerConfigSet = _reflection.GeneratedProtocolMessageType('ConnectionPoolerConfigSet', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTIONPOOLERCONFIGSET,
  '__module__' : 'yandex.cloud.mdb.greenplum.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.greenplum.v1.ConnectionPoolerConfigSet)
  })
_sym_db.RegisterMessage(ConnectionPoolerConfigSet)


DESCRIPTOR._options = None
_GREENPLUMCONFIGSET6_17.fields_by_name['effective_config']._options = None
_GREENPLUMCONFIGSET6_19.fields_by_name['effective_config']._options = None
_CONNECTIONPOOLERCONFIGSET.fields_by_name['effective_config']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/logging/v1/log_group_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.logging.v1 import log_group_pb2 as yandex_dot_cloud_dot_logging_dot_v1_dot_log__group__pb2
from yandex.cloud.logging.v1 import log_resource_pb2 as yandex_dot_cloud_dot_logging_dot_v1_dot_log__resource__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/logging/v1/log_group_service.proto',
  package='yandex.cloud.logging.v1',
  syntax='proto3',
  serialized_options=b'\n\033yandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;logging',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/yandex/cloud/logging/v1/log_group_service.proto\x12\x17yandex.cloud.logging.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/access/access.proto\x1a\'yandex/cloud/logging/v1/log_group.proto\x1a*yandex/cloud/logging/v1/log_resource.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"8\n\x12GetLogGroupRequest\x12\"\n\x0clog_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\"=\n\x17GetLogGroupStatsRequest\x12\"\n\x0clog_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\"\x85\x01\n\x14ListLogGroupsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"c\n\x15ListLogGroupsResponse\x12\x31\n\x06groups\x18\x01 \x03(\x0b\x32!.yandex.cloud.logging.v1.LogGroup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xa0\x03\n\x15\x43reateLogGroupRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12\x34\n\x04name\x18\x02 \x01(\tB&\xf2\xc7\x31\"([a-z]([-a-z0-9]{1,61}[a-z0-9])?)?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8b\x01\n\x06labels\x18\x04 \x03(\x0b\x32:.yandex.cloud.logging.v1.CreateLogGroupRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12\x33\n\x10retention_period\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1e\n\x0b\x64\x61ta_stream\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=512\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\".\n\x16\x43reateLogGroupMetadata\x12\x14\n\x0clog_group_id\x18\x01 \x01(\t\"\xd4\x03\n\x15UpdateLogGroupRequest\x12\"\n\x0clog_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x34\n\x04name\x18\x03 \x01(\tB&\xf2\xc7\x31\"([a-z]([-a-z0-9]{1,61}[a-z0-9])?)?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8b\x01\n\x06labels\x18\x05 \x03(\x0b\x32:.yandex.cloud.logging.v1.UpdateLogGroupRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12\x33\n\x10retention_period\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1e\n\x0b\x64\x61ta_stream\x18\x07 \x01(\tB\t\x8a\xc8\x31\x05<=512\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\".\n\x16UpdateLogGroupMetadata\x12\x14\n\x0clog_group_id\x18\x01 \x01(\t\";\n\x15\x44\x65leteLogGroupRequest\x12\"\n\x0clog_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\".\n\x16\x44\x65leteLogGroupMetadata\x12\x14\n\x0clog_group_id\x18\x01 \x01(\t\"S\n\x14ListResourcesRequest\x12\"\n\x0clog_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12\x17\n\x04type\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=256\"U\n\x15ListResourcesResponse\x12<\n\tresources\x18\x01 \x03(\x0b\x32).yandex.cloud.logging.v1.LogGroupResource\"\x95\x01\n\x15ListOperationsRequest\x12\"\n\x0clog_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"h\n\x16ListOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"P\n\x18GetLogGroupStatsResponse\x12\x14\n\x0clog_group_id\x18\x01 \x01(\t\x12\r\n\x05\x62ytes\x18\x02 \x01(\x03\x12\x0f\n\x07records\x18\x03 \x01(\x03\x32\xc8\x0f\n\x0fLogGroupService\x12\x83\x01\n\x03Get\x12+.yandex.cloud.logging.v1.GetLogGroupRequest\x1a!.yandex.cloud.logging.v1.LogGroup\",\x82\xd3\xe4\x93\x02&\x12$/logging/v1/logGroups/{log_group_id}\x12\xa0\x01\n\x05Stats\x12\x30.yandex.cloud.logging.v1.GetLogGroupStatsRequest\x1a\x31.yandex.cloud.logging.v1.GetLogGroupStatsResponse\"2\x82\xd3\xe4\x93\x02,\x12*/logging/v1/logGroups/{log_group_id}/stats\x12\x84\x01\n\x04List\x12-.yandex.cloud.logging.v1.ListLogGroupsRequest\x1a..yandex.cloud.logging.v1.ListLogGroupsResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/logging/v1/logGroups\x12\xa3\x01\n\x06\x43reate\x12..yandex.cloud.logging.v1.CreateLogGroupRequest\x1a!.yandex.cloud.operation.Operation\"F\x82\xd3\xe4\x93\x02\x1a\"\x15/logging/v1/logGroups:\x01*\xb2\xd2*\"\n\x16\x43reateLogGroupMetadata\x12\x08LogGroup\x12\xb2\x01\n\x06Update\x12..yandex.cloud.logging.v1.UpdateLogGroupRequest\x1a!.yandex.cloud.operation.Operation\"U\x82\xd3\xe4\x93\x02)2$/logging/v1/logGroups/{log_group_id}:\x01*\xb2\xd2*\"\n\x16UpdateLogGroupMetadata\x12\x08LogGroup\x12\xbc\x01\n\x06\x44\x65lete\x12..yandex.cloud.logging.v1.DeleteLogGroupRequest\x1a!.yandex.cloud.operation.Operation\"_\x82\xd3\xe4\x93\x02&*$/logging/v1/logGroups/{log_group_id}\xb2\xd2*/\n\x16\x44\x65leteLogGroupMetadata\x12\x15google.protobuf.Empty\x12\xaa\x01\n\rListResources\x12-.yandex.cloud.logging.v1.ListResourcesRequest\x1a..yandex.cloud.logging.v1.ListResourcesResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/logging/v1/logGroups/{log_group_id}:listResources\x12\xaa\x01\n\x0eListOperations\x12..yandex.cloud.logging.v1.ListOperationsRequest\x1a/.yandex.cloud.logging.v1.ListOperationsResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//logging/v1/logGroups/{log_group_id}/operations\x12\xb5\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/logging/v1/logGroups/{resource_id}:listAccessBindings\x12\xe4\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"}\x82\xd3\xe4\x93\x02:\"5/logging/v1/logGroups/{resource_id}:setAccessBindings:\x01*\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x12\xf1\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x83\x01\x82\xd3\xe4\x93\x02=28/logging/v1/logGroups/{resource_id}:updateAccessBindings:\x01*\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.EmptyBb\n\x1byandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;loggingb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_access_dot_access__pb2.DESCRIPTOR,yandex_dot_cloud_dot_logging_dot_v1_dot_log__group__pb2.DESCRIPTOR,yandex_dot_cloud_dot_logging_dot_v1_dot_log__resource__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETLOGGROUPREQUEST = _descriptor.Descriptor(
  name='GetLogGroupRequest',
  full_name='yandex.cloud.logging.v1.GetLogGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_group_id', full_name='yandex.cloud.logging.v1.GetLogGroupRequest.log_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=64', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=396,
  serialized_end=452,
)


_GETLOGGROUPSTATSREQUEST = _descriptor.Descriptor(
  name='GetLogGroupStatsRequest',
  full_name='yandex.cloud.logging.v1.GetLogGroupStatsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_group_id', full_name='yandex.cloud.logging.v1.GetLogGroupStatsRequest.log_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=64', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=454,
  serialized_end=515,
)


_LISTLOGGROUPSREQUEST = _descriptor.Descriptor(
  name='ListLogGroupsRequest',
  full_name='yandex.cloud.logging.v1.ListLogGroupsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.logging.v1.ListLogGroupsRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=64', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.logging.v1.ListLogGroupsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.logging.v1.ListLogGroupsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.logging.v1.ListLogGroupsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=518,
  serialized_end=651,
)


_LISTLOGGROUPSRESPONSE = _descriptor.Descriptor(
  name='ListLogGroupsResponse',
  full_name='yandex.cloud.logging.v1.ListLogGroupsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='groups', full_name='yandex.cloud.logging.v1.ListLogGroupsResponse.groups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.logging.v1.ListLogGroupsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=653,
  serialized_end=752,
)


_CREATELOGGROUPREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.logging.v1.CreateLogGroupRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.logging.v1.CreateLogGroupRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.logging.v1.CreateLogGroupRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1126,
  serialized_end=1171,
)

_CREATELOGGROUPREQUEST = _descriptor.Descriptor(
  name='CreateLogGroupRequest',
  full_name='yandex.cloud.logging.v1.CreateLogGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.logging.v1.CreateLogGroupRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=64', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.logging.v1.CreateLogGroupRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\"([a-z]([-a-z0-9]{1,61}[a-z0-9])?)?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.logging.v1.CreateLogGroupRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.logging.v1.CreateLogGroupRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\0041-63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retention_period', full_name='yandex.cloud.logging.v1.CreateLogGroupRequest.retention_period', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_stream', full_name='yandex.cloud.logging.v1.CreateLogGroupRequest.data_stream', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=512', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATELOGGROUPREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=755,
  serialized_end=1171,
)


_CREATELOGGROUPMETADATA = _descriptor.Descriptor(
  name='CreateLogGroupMetadata',
  full_name='yandex.cloud.logging.v1.CreateLogGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_group_id', full_name='yandex.cloud.logging.v1.CreateLogGroupMetadata.log_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1173,
  serialized_end=1219,
)


_UPDATELOGGROUPREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.logging.v1.UpdateLogGroupRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.logging.v1.UpdateLogGroupRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.logging.v1.UpdateLogGroupRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1126,
  serialized_end=1171,
)

_UPDATELOGGROUPREQUEST = _descriptor.Descriptor(
  name='UpdateLogGroupRequest',
  full_name='yandex.cloud.logging.v1.UpdateLogGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_group_id', full_name='yandex.cloud.logging.v1.UpdateLogGroupRequest.log_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=64', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.logging.v1.UpdateLogGroupRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.logging.v1.UpdateLogGroupRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\"([a-z]([-a-z0-9]{1,61}[a-z0-9])?)?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.logging.v1.UpdateLogGroupRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.logging.v1.UpdateLogGroupRequest.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\0041-63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retention_period', full_name='yandex.cloud.logging.v1.UpdateLogGroupRequest.retention_period', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_stream', full_name='yandex.cloud.logging.v1.UpdateLogGroupRequest.data_stream', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=512', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATELOGGROUPREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1222,
  serialized_end=1690,
)


_UPDATELOGGROUPMETADATA = _descriptor.Descriptor(
  name='UpdateLogGroupMetadata',
  full_name='yandex.cloud.logging.v1.UpdateLogGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_group_id', full_name='yandex.cloud.logging.v1.UpdateLogGroupMetadata.log_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1692,
  serialized_end=1738,
)


_DELETELOGGROUPREQUEST = _descriptor.Descriptor(
  name='DeleteLogGroupRequest',
  full_name='yandex.cloud.logging.v1.DeleteLogGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_group_id', full_name='yandex.cloud.logging.v1.DeleteLogGroupRequest.log_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=64', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1740,
  serialized_end=1799,
)


_DELETELOGGROUPMETADATA = _descriptor.Descriptor(
  name='DeleteLogGroupMetadata',
  full_name='yandex.cloud.logging.v1.DeleteLogGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_group_id', full_name='yandex.cloud.logging.v1.DeleteLogGroupMetadata.log_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1801,
  serialized_end=1847,
)


_LISTRESOURCESREQUEST = _descriptor.Descriptor(
  name='ListResourcesRequest',
  full_name='yandex.cloud.logging.v1.ListResourcesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_group_id', full_name='yandex.cloud.logging.v1.ListResourcesRequest.log_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=64', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='yandex.cloud.logging.v1.ListResourcesRequest.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1849,
  serialized_end=1932,
)


_LISTRESOURCESRESPONSE = _descriptor.Descriptor(
  name='ListResourcesResponse',
  full_name='yandex.cloud.logging.v1.ListResourcesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.logging.v1.ListResourcesResponse.resources', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1934,
  serialized_end=2019,
)


_LISTOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListOperationsRequest',
  full_name='yandex.cloud.logging.v1.ListOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_group_id', full_name='yandex.cloud.logging.v1.ListOperationsRequest.log_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=64', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.logging.v1.ListOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.logging.v1.ListOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.logging.v1.ListOperationsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2022,
  serialized_end=2171,
)


_LISTOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListOperationsResponse',
  full_name='yandex.cloud.logging.v1.ListOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.logging.v1.ListOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.logging.v1.ListOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2173,
  serialized_end=2277,
)


_GETLOGGROUPSTATSRESPONSE = _descriptor.Descriptor(
  name='GetLogGroupStatsResponse',
  full_name='yandex.cloud.logging.v1.GetLogGroupStatsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_group_id', full_name='yandex.cloud.logging.v1.GetLogGroupStatsResponse.log_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes', full_name='yandex.cloud.logging.v1.GetLogGroupStatsResponse.bytes', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='records', full_name='yandex.cloud.logging.v1.GetLogGroupStatsResponse.records', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2279,
  serialized_end=2359,
)

_LISTLOGGROUPSRESPONSE.fields_by_name['groups'].message_type = yandex_dot_cloud_dot_logging_dot_v1_dot_log__group__pb2._LOGGROUP
_CREATELOGGROUPREQUEST_LABELSENTRY.containing_type = _CREATELOGGROUPREQUEST
_CREATELOGGROUPREQUEST.fields_by_name['labels'].message_type = _CREATELOGGROUPREQUEST_LABELSENTRY
_CREATELOGGROUPREQUEST.fields_by_name['retention_period'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_UPDATELOGGROUPREQUEST_LABELSENTRY.containing_type = _UPDATELOGGROUPREQUEST
_UPDATELOGGROUPREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATELOGGROUPREQUEST.fields_by_name['labels'].message_type = _UPDATELOGGROUPREQUEST_LABELSENTRY
_UPDATELOGGROUPREQUEST.fields_by_name['retention_period'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_LISTRESOURCESRESPONSE.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_logging_dot_v1_dot_log__resource__pb2._LOGGROUPRESOURCE
_LISTOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['GetLogGroupRequest'] = _GETLOGGROUPREQUEST
DESCRIPTOR.message_types_by_name['GetLogGroupStatsRequest'] = _GETLOGGROUPSTATSREQUEST
DESCRIPTOR.message_types_by_name['ListLogGroupsRequest'] = _LISTLOGGROUPSREQUEST
DESCRIPTOR.message_types_by_name['ListLogGroupsResponse'] = _LISTLOGGROUPSRESPONSE
DESCRIPTOR.message_types_by_name['CreateLogGroupRequest'] = _CREATELOGGROUPREQUEST
DESCRIPTOR.message_types_by_name['CreateLogGroupMetadata'] = _CREATELOGGROUPMETADATA
DESCRIPTOR.message_types_by_name['UpdateLogGroupRequest'] = _UPDATELOGGROUPREQUEST
DESCRIPTOR.message_types_by_name['UpdateLogGroupMetadata'] = _UPDATELOGGROUPMETADATA
DESCRIPTOR.message_types_by_name['DeleteLogGroupRequest'] = _DELETELOGGROUPREQUEST
DESCRIPTOR.message_types_by_name['DeleteLogGroupMetadata'] = _DELETELOGGROUPMETADATA
DESCRIPTOR.message_types_by_name['ListResourcesRequest'] = _LISTRESOURCESREQUEST
DESCRIPTOR.message_types_by_name['ListResourcesResponse'] = _LISTRESOURCESRESPONSE
DESCRIPTOR.message_types_by_name['ListOperationsRequest'] = _LISTOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListOperationsResponse'] = _LISTOPERATIONSRESPONSE
DESCRIPTOR.message_types_by_name['GetLogGroupStatsResponse'] = _GETLOGGROUPSTATSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetLogGroupRequest = _reflection.GeneratedProtocolMessageType('GetLogGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLOGGROUPREQUEST,
  '__module__' : 'yandex.cloud.logging.v1.log_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.GetLogGroupRequest)
  })
_sym_db.RegisterMessage(GetLogGroupRequest)

GetLogGroupStatsRequest = _reflection.GeneratedProtocolMessageType('GetLogGroupStatsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLOGGROUPSTATSREQUEST,
  '__module__' : 'yandex.cloud.logging.v1.log_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.GetLogGroupStatsRequest)
  })
_sym_db.RegisterMessage(GetLogGroupStatsRequest)

ListLogGroupsRequest = _reflection.GeneratedProtocolMessageType('ListLogGroupsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTLOGGROUPSREQUEST,
  '__module__' : 'yandex.cloud.logging.v1.log_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.ListLogGroupsRequest)
  })
_sym_db.RegisterMessage(ListLogGroupsRequest)

ListLogGroupsResponse = _reflection.GeneratedProtocolMessageType('ListLogGroupsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTLOGGROUPSRESPONSE,
  '__module__' : 'yandex.cloud.logging.v1.log_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.ListLogGroupsResponse)
  })
_sym_db.RegisterMessage(ListLogGroupsResponse)

CreateLogGroupRequest = _reflection.GeneratedProtocolMessageType('CreateLogGroupRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATELOGGROUPREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.logging.v1.log_group_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.CreateLogGroupRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATELOGGROUPREQUEST,
  '__module__' : 'yandex.cloud.logging.v1.log_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.CreateLogGroupRequest)
  })
_sym_db.RegisterMessage(CreateLogGroupRequest)
_sym_db.RegisterMessage(CreateLogGroupRequest.LabelsEntry)

CreateLogGroupMetadata = _reflection.GeneratedProtocolMessageType('CreateLogGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATELOGGROUPMETADATA,
  '__module__' : 'yandex.cloud.logging.v1.log_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.CreateLogGroupMetadata)
  })
_sym_db.RegisterMessage(CreateLogGroupMetadata)

UpdateLogGroupRequest = _reflection.GeneratedProtocolMessageType('UpdateLogGroupRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATELOGGROUPREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.logging.v1.log_group_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.UpdateLogGroupRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATELOGGROUPREQUEST,
  '__module__' : 'yandex.cloud.logging.v1.log_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.UpdateLogGroupRequest)
  })
_sym_db.RegisterMessage(UpdateLogGroupRequest)
_sym_db.RegisterMessage(UpdateLogGroupRequest.LabelsEntry)

UpdateLogGroupMetadata = _reflection.GeneratedProtocolMessageType('UpdateLogGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELOGGROUPMETADATA,
  '__module__' : 'yandex.cloud.logging.v1.log_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.UpdateLogGroupMetadata)
  })
_sym_db.RegisterMessage(UpdateLogGroupMetadata)

DeleteLogGroupRequest = _reflection.GeneratedProtocolMessageType('DeleteLogGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETELOGGROUPREQUEST,
  '__module__' : 'yandex.cloud.logging.v1.log_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.DeleteLogGroupRequest)
  })
_sym_db.RegisterMessage(DeleteLogGroupRequest)

DeleteLogGroupMetadata = _reflection.GeneratedProtocolMessageType('DeleteLogGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETELOGGROUPMETADATA,
  '__module__' : 'yandex.cloud.logging.v1.log_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.DeleteLogGroupMetadata)
  })
_sym_db.RegisterMessage(DeleteLogGroupMetadata)

ListResourcesRequest = _reflection.GeneratedProtocolMessageType('ListResourcesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTRESOURCESREQUEST,
  '__module__' : 'yandex.cloud.logging.v1.log_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.ListResourcesRequest)
  })
_sym_db.RegisterMessage(ListResourcesRequest)

ListResourcesResponse = _reflection.GeneratedProtocolMessageType('ListResourcesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTRESOURCESRESPONSE,
  '__module__' : 'yandex.cloud.logging.v1.log_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.ListResourcesResponse)
  })
_sym_db.RegisterMessage(ListResourcesResponse)

ListOperationsRequest = _reflection.GeneratedProtocolMessageType('ListOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTOPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.logging.v1.log_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.ListOperationsRequest)
  })
_sym_db.RegisterMessage(ListOperationsRequest)

ListOperationsResponse = _reflection.GeneratedProtocolMessageType('ListOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTOPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.logging.v1.log_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.ListOperationsResponse)
  })
_sym_db.RegisterMessage(ListOperationsResponse)

GetLogGroupStatsResponse = _reflection.GeneratedProtocolMessageType('GetLogGroupStatsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLOGGROUPSTATSRESPONSE,
  '__module__' : 'yandex.cloud.logging.v1.log_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.GetLogGroupStatsResponse)
  })
_sym_db.RegisterMessage(GetLogGroupStatsResponse)


DESCRIPTOR._options = None
_GETLOGGROUPREQUEST.fields_by_name['log_group_id']._options = None
_GETLOGGROUPSTATSREQUEST.fields_by_name['log_group_id']._options = None
_LISTLOGGROUPSREQUEST.fields_by_name['folder_id']._options = None
_LISTLOGGROUPSREQUEST.fields_by_name['page_token']._options = None
_LISTLOGGROUPSREQUEST.fields_by_name['filter']._options = None
_CREATELOGGROUPREQUEST_LABELSENTRY._options = None
_CREATELOGGROUPREQUEST.fields_by_name['folder_id']._options = None
_CREATELOGGROUPREQUEST.fields_by_name['name']._options = None
_CREATELOGGROUPREQUEST.fields_by_name['description']._options = None
_CREATELOGGROUPREQUEST.fields_by_name['labels']._options = None
_CREATELOGGROUPREQUEST.fields_by_name['data_stream']._options = None
_UPDATELOGGROUPREQUEST_LABELSENTRY._options = None
_UPDATELOGGROUPREQUEST.fields_by_name['log_group_id']._options = None
_UPDATELOGGROUPREQUEST.fields_by_name['name']._options = None
_UPDATELOGGROUPREQUEST.fields_by_name['description']._options = None
_UPDATELOGGROUPREQUEST.fields_by_name['labels']._options = None
_UPDATELOGGROUPREQUEST.fields_by_name['data_stream']._options = None
_DELETELOGGROUPREQUEST.fields_by_name['log_group_id']._options = None
_LISTRESOURCESREQUEST.fields_by_name['log_group_id']._options = None
_LISTRESOURCESREQUEST.fields_by_name['type']._options = None
_LISTOPERATIONSREQUEST.fields_by_name['log_group_id']._options = None
_LISTOPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTOPERATIONSREQUEST.fields_by_name['page_token']._options = None
_LISTOPERATIONSREQUEST.fields_by_name['filter']._options = None

_LOGGROUPSERVICE = _descriptor.ServiceDescriptor(
  name='LogGroupService',
  full_name='yandex.cloud.logging.v1.LogGroupService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2362,
  serialized_end=4354,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.logging.v1.LogGroupService.Get',
    index=0,
    containing_service=None,
    input_type=_GETLOGGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_logging_dot_v1_dot_log__group__pb2._LOGGROUP,
    serialized_options=b'\202\323\344\223\002&\022$/logging/v1/logGroups/{log_group_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Stats',
    full_name='yandex.cloud.logging.v1.LogGroupService.Stats',
    index=1,
    containing_service=None,
    input_type=_GETLOGGROUPSTATSREQUEST,
    output_type=_GETLOGGROUPSTATSRESPONSE,
    serialized_options=b'\202\323\344\223\002,\022*/logging/v1/logGroups/{log_group_id}/stats',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.logging.v1.LogGroupService.List',
    index=2,
    containing_service=None,
    input_type=_LISTLOGGROUPSREQUEST,
    output_type=_LISTLOGGROUPSRESPONSE,
    serialized_options=b'\202\323\344\223\002\027\022\025/logging/v1/logGroups',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.logging.v1.LogGroupService.Create',
    index=3,
    containing_service=None,
    input_type=_CREATELOGGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\032\"\025/logging/v1/logGroups:\001*\262\322*\"\n\026CreateLogGroupMetadata\022\010LogGroup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.logging.v1.LogGroupService.Update',
    index=4,
    containing_service=None,
    input_type=_UPDATELOGGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002)2$/logging/v1/logGroups/{log_group_id}:\001*\262\322*\"\n\026UpdateLogGroupMetadata\022\010LogGroup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.logging.v1.LogGroupService.Delete',
    index=5,
    containing_service=None,
    input_type=_DELETELOGGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002&*$/logging/v1/logGroups/{log_group_id}\262\322*/\n\026DeleteLogGroupMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListResources',
    full_name='yandex.cloud.logging.v1.LogGroupService.ListResources',
    index=6,
    containing_service=None,
    input_type=_LISTRESOURCESREQUEST,
    output_type=_LISTRESOURCESRESPONSE,
    serialized_options=b'\202\323\344\223\0024\0222/logging/v1/logGroups/{log_group_id}:listResources',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.logging.v1.LogGroupService.ListOperations',
    index=7,
    containing_service=None,
    input_type=_LISTOPERATIONSREQUEST,
    output_type=_LISTOPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\0021\022//logging/v1/logGroups/{log_group_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListAccessBindings',
    full_name='yandex.cloud.logging.v1.LogGroupService.ListAccessBindings',
    index=8,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSRESPONSE,
    serialized_options=b'\202\323\344\223\0028\0226/logging/v1/logGroups/{resource_id}:listAccessBindings',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetAccessBindings',
    full_name='yandex.cloud.logging.v1.LogGroupService.SetAccessBindings',
    index=9,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._SETACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002:\"5/logging/v1/logGroups/{resource_id}:setAccessBindings:\001*\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateAccessBindings',
    full_name='yandex.cloud.logging.v1.LogGroupService.UpdateAccessBindings',
    index=10,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._UPDATEACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002=28/logging/v1/logGroups/{resource_id}:updateAccessBindings:\001*\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_LOGGROUPSERVICE)

DESCRIPTOR.services_by_name['LogGroupService'] = _LOGGROUPSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/apploadbalancer/v1/logging.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/apploadbalancer/v1/logging.proto',
  package='yandex.cloud.apploadbalancer.v1',
  syntax='proto3',
  serialized_options=b'\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancer',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-yandex/cloud/apploadbalancer/v1/logging.proto\x12\x1fyandex.cloud.apploadbalancer.v1\x1a\x1dyandex/cloud/validation.proto\"\x8e\x01\n\x0eLogDiscardRule\x12\x1a\n\x05\x63odes\x18\x01 \x03(\x03\x42\x0b\xfa\xc7\x31\x07\x31\x30\x30-599\x12\x44\n\tintervals\x18\x02 \x03(\x0e\x32\x31.yandex.cloud.apploadbalancer.v1.HttpCodeInterval\x12\x1a\n\x07percent\x18\x03 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\"{\n\nLogOptions\x12\x14\n\x0clog_group_id\x18\x01 \x01(\t\x12\x46\n\rdiscard_rules\x18\x02 \x03(\x0b\x32/.yandex.cloud.apploadbalancer.v1.LogDiscardRule\x12\x0f\n\x07\x64isable\x18\x03 \x01(\x08*\xc2\x01\n\x10HttpCodeInterval\x12\"\n\x1eHTTP_CODE_INTERVAL_UNSPECIFIED\x10\x00\x12\x1a\n\x16HTTP_CODE_INTERVAL_1XX\x10\x01\x12\x1a\n\x16HTTP_CODE_INTERVAL_2XX\x10\x02\x12\x1a\n\x16HTTP_CODE_INTERVAL_3XX\x10\x03\x12\x1a\n\x16HTTP_CODE_INTERVAL_4XX\x10\x04\x12\x1a\n\x16HTTP_CODE_INTERVAL_5XX\x10\x05\x42z\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancerb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])

_HTTPCODEINTERVAL = _descriptor.EnumDescriptor(
  name='HttpCodeInterval',
  full_name='yandex.cloud.apploadbalancer.v1.HttpCodeInterval',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HTTP_CODE_INTERVAL_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTP_CODE_INTERVAL_1XX', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTP_CODE_INTERVAL_2XX', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTP_CODE_INTERVAL_3XX', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTP_CODE_INTERVAL_4XX', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTP_CODE_INTERVAL_5XX', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=384,
  serialized_end=578,
)
_sym_db.RegisterEnumDescriptor(_HTTPCODEINTERVAL)

HttpCodeInterval = enum_type_wrapper.EnumTypeWrapper(_HTTPCODEINTERVAL)
HTTP_CODE_INTERVAL_UNSPECIFIED = 0
HTTP_CODE_INTERVAL_1XX = 1
HTTP_CODE_INTERVAL_2XX = 2
HTTP_CODE_INTERVAL_3XX = 3
HTTP_CODE_INTERVAL_4XX = 4
HTTP_CODE_INTERVAL_5XX = 5



_LOGDISCARDRULE = _descriptor.Descriptor(
  name='LogDiscardRule',
  full_name='yandex.cloud.apploadbalancer.v1.LogDiscardRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='codes', full_name='yandex.cloud.apploadbalancer.v1.LogDiscardRule.codes', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\007100-599', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='intervals', full_name='yandex.cloud.apploadbalancer.v1.LogDiscardRule.intervals', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='percent', full_name='yandex.cloud.apploadbalancer.v1.LogDiscardRule.percent', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0050-100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=114,
  serialized_end=256,
)


_LOGOPTIONS = _descriptor.Descriptor(
  name='LogOptions',
  full_name='yandex.cloud.apploadbalancer.v1.LogOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_group_id', full_name='yandex.cloud.apploadbalancer.v1.LogOptions.log_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='discard_rules', full_name='yandex.cloud.apploadbalancer.v1.LogOptions.discard_rules', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable', full_name='yandex.cloud.apploadbalancer.v1.LogOptions.disable', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=258,
  serialized_end=381,
)

_LOGDISCARDRULE.fields_by_name['intervals'].enum_type = _HTTPCODEINTERVAL
_LOGOPTIONS.fields_by_name['discard_rules'].message_type = _LOGDISCARDRULE
DESCRIPTOR.message_types_by_name['LogDiscardRule'] = _LOGDISCARDRULE
DESCRIPTOR.message_types_by_name['LogOptions'] = _LOGOPTIONS
DESCRIPTOR.enum_types_by_name['HttpCodeInterval'] = _HTTPCODEINTERVAL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LogDiscardRule = _reflection.GeneratedProtocolMessageType('LogDiscardRule', (_message.Message,), {
  'DESCRIPTOR' : _LOGDISCARDRULE,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.logging_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.LogDiscardRule)
  })
_sym_db.RegisterMessage(LogDiscardRule)

LogOptions = _reflection.GeneratedProtocolMessageType('LogOptions', (_message.Message,), {
  'DESCRIPTOR' : _LOGOPTIONS,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.logging_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.LogOptions)
  })
_sym_db.RegisterMessage(LogOptions)


DESCRIPTOR._options = None
_LOGDISCARDRULE.fields_by_name['codes']._options = None
_LOGDISCARDRULE.fields_by_name['percent']._options = None
# @@protoc_insertion_point(module_scope)
